<?php

namespace Kylin\LawCase\Enums;

/**
 * 文档访问级别枚举
 */
enum AccessLevel: string
{
    case PUBLIC = 'public';
    case CASE_MEMBERS = 'case_members';
    case PRINCIPAL_LAWYER = 'principal_lawyer';
    case OWNER_ONLY = 'owner_only';

    public function label(): string
    {
        return match($this) {
            self::PUBLIC => '公开',
            self::CASE_MEMBERS => '案件成员',
            self::PRINCIPAL_LAWYER => '主办律师',
            self::OWNER_ONLY => '仅上传者',
        };
    }
}
