<?php

namespace Kylin\LawCase\Enums;

/**
 * 计费方式枚举
 */
enum ChargeMethod: string
{
    case HOURLY = 'hourly';
    case FIXED = 'fixed';
    case CONTINGENCY = 'contingency';

    public function label(): string
    {
        return match($this) {
            self::HOURLY => '计时',
            self::FIXED => '固定',
            self::CONTINGENCY => '风险代理',
        };
    }
}
