<?php

namespace Kylin\LawCase\Enums;

/**
 * 费用类型枚举
 */
enum FeeType: string
{
    case RETAINER = 'retainer';
    case CONTINGENCY = 'contingency';
    case HOURLY = 'hourly';
    case FIXED = 'fixed';
    case EXPENSE = 'expense';

    public function label(): string
    {
        return match($this) {
            self::RETAINER => '顾问费',
            self::CONTINGENCY => '风险代理费',
            self::HOURLY => '计时收费',
            self::FIXED => '固定收费',
            self::EXPENSE => '代垫费用',
        };
    }
}
