<?php

namespace Kylin\LawCase\Enums;

/**
 * 日程类型枚举
 */
enum ScheduleType: string
{
    case HEARING = 'hearing';
    case MEETING = 'meeting';
    case DEADLINE = 'deadline';
    case COURT_DATE = 'court_date';
    case OTHER = 'other';

    public function label(): string
    {
        return match($this) {
            self::HEARING => '庭审',
            self::MEETING => '会议',
            self::DEADLINE => '期限',
            self::COURT_DATE => '开庭日',
            self::OTHER => '其他',
        };
    }
}
