<?php

namespace Kylin\LawCase\Events;

use Kylin\LawCase\Models\CaseModel;
use Kylin\LawCase\Enums\CaseStatus;
use Illuminate\Broadcasting\InteractsWithSockets;
use Illuminate\Foundation\Events\Dispatchable;

/**
 * 案件状态变更事件
 */
class CaseStatusChanged
{
    use Dispatchable, InteractsWithSockets;

    public function __construct(
        public CaseModel $case,
        public CaseStatus $oldStatus,
        public CaseStatus $newStatus,
        public string $reason = ''
    ) {}
}
