<?php

namespace Kylin\LawCase\Enums;

/**
 * 文档类型枚举
 */
enum DocType: string
{
    case PLEADING = 'pleading';
    case EVIDENCE = 'evidence';
    case CONTRACT = 'contract';
    case CORRESPONDENCE = 'correspondence';
    case COURT_DOCUMENT = 'court_document';
    case OPINION = 'opinion';
    case OTHER = 'other';

    public function label(): string
    {
        return match($this) {
            self::PLEADING => '诉状',
            self::EVIDENCE => '证据',
            self::CONTRACT => '合同',
            self::CORRESPONDENCE => '函件',
            self::COURT_DOCUMENT => '法院文书',
            self::OPINION => '法律意见',
            self::OTHER => '其他',
        };
    }
}
