<?php

namespace Kylin\LawCase\Models;

use Illuminate\Database\Eloquent\Model;

/**
 * 审计访问日志模型
 *
 * 记录敏感数据访问日志，包括访问目的、IP地址等。
 *
 * @property string $target_type  访问目标类型
 * @property int    $target_id    访问目标ID
 * @property string $action       访问动作
 * @property string $purpose      访问目的
 * @property string $ip_address   IP地址
 */
class AuditAccessLog extends Model
{
    protected $table = 'kylin_law_audit_access_logs';

    protected $fillable = [
        'user_id',
        'target_type',
        'target_id',
        'action',
        'purpose',
        'ip_address',
    ];

    public function user()
    {
        return $this->belongsTo(\App\Models\User::class);
    }
}
