<?php

namespace Kylin\LawCase\Models;

use Illuminate\Database\Eloquent\Model;

/**
 * 文档模板模型
 *
 * 管理法律文书模板，支持变量替换生成文档。
 *
 * @property string $name             模板名称
 * @property string $doc_type         文档类型
 * @property string $template_content 模板内容
 * @property string $variables        模板变量
 */
class DocumentTemplate extends Model
{
    protected $table = 'kylin_law_document_templates';

    protected $fillable = [
        'name',
        'doc_type',
        'template_content',
        'variables',
        'description',
    ];

    protected $casts = [
        'variables' => 'array',
    ];
}
