<?php

namespace Kylin\LawCase\Events;

use Kylin\LawCase\Models\CaseModel;
use Illuminate\Broadcasting\InteractsWithSockets;
use Illuminate\Foundation\Events\Dispatchable;

/**
 * 案件创建事件
 */
class CaseCreated
{
    use Dispatchable, InteractsWithSockets;

    public function __construct(
        public CaseModel $case
    ) {}
}
