<?php

namespace Kylin\LawCase\Events;

use Kylin\LawCase\Models\Schedule;

/**
 * 日程提醒事件
 */
class ScheduleReminder
{
    public function __construct(
        public Schedule $schedule,
        public int $daysBefore
    ) {}
}
