<?php

namespace Kylin\LawCase\Enums;

/**
 * 案件类型枚举
 */
enum CaseType: string
{
    case CIVIL = 'civil';               // 民事案件
    case CRIMINAL = 'criminal';          // 刑事案件
    case ADMINISTRATIVE = 'administrative'; // 行政案件
    case NON_LITIGATION = 'non_litigation'; // 非诉案件
    case LABOR = 'labor';                // 劳动争议
    case CONTRACT = 'contract';          // 合同纠纷
    case INTELLECTUAL = 'intellectual';  // 知识产权
    case REAL_ESTATE = 'real_estate';    // 房产纠纷
    case COMPANY = 'company';            // 公司法务
    case TORT = 'tort';                  // 侵权责任
    case MARRIAGE = 'marriage';          // 婚姻家事
    case ARBITRATION = 'arbitration';    // 仲裁案件

    public function label(): string
    {
        return match ($this) {
            self::CIVIL => '民事案件',
            self::CRIMINAL => '刑事案件',
            self::ADMINISTRATIVE => '行政案件',
            self::NON_LITIGATION => '非诉案件',
            self::LABOR => '劳动争议',
            self::CONTRACT => '合同纠纷',
            self::INTELLECTUAL => '知识产权',
            self::REAL_ESTATE => '房产纠纷',
            self::COMPANY => '公司法务',
            self::TORT => '侵权责任',
            self::MARRIAGE => '婚姻家事',
            self::ARBITRATION => '仲裁案件',
        };
    }
}
