<?php

namespace Kylin\LawCase\Facades;

use Illuminate\Support\Facades\Facade;

/**
 * 律所案件系统门面
 *
 * 提供 CaseService 的静态访问入口。
 */
class KylinLawCase extends Facade
{
    protected static function getFacadeAccessor(): string
    {
        return \Kylin\LawCase\Services\CaseService::class;
    }
}
