<?php

namespace Kylin\LawCase\Enums;

/**
 * 角色类型枚举
 */
enum RoleType: string
{
    case SUPER_ADMIN = 'super_admin';   // 超级管理员
    case PARTNER = 'partner';           // 合伙人
    case LAWYER = 'lawyer';             // 律师
    case ASSISTANT = 'assistant';       // 律师助理
    case FINANCE = 'finance';           // 财务
    case ADMIN = 'admin';               // 行政

    public function label(): string
    {
        return match ($this) {
            self::SUPER_ADMIN => '超级管理员',
            self::PARTNER => '合伙人',
            self::LAWYER => '律师',
            self::ASSISTANT => '律师助理',
            self::FINANCE => '财务',
            self::ADMIN => '行政',
        };
    }
}
